@echo off

rem ********************************************************************************
rem *
rem * INSTOS.BAT
rem *
rem * This file controls the installation of Microsoft(R) Windows Operating Systems
rem * for the ServerGuide Scripting Toolkit.
rem *
rem * This batch file is called by the runinst.bat.
rem *
rem ********************************************************************************


rem ********************************************************************************
rem * Clean up unneeded environment variables
rem ********************************************************************************
echo Calling clear environment space
call clrenv.bat

rem ********************************************************************************
rem * If Altiris, jump to special section
rem ********************************************************************************
if %DPLY_TYPE%==4 goto ALT_INST

rem ********************************************************************************
rem * Clear persistent storage, before continuing.
rem ********************************************************************************
echo Clear persistent, before continuing
savestat.exe /set2=0 > nul

rem ********************************************************************************
rem * Check for errors: SAVESTAT.EXE
rem ********************************************************************************
if not errorlevel 255 goto FORMATS
echo An error occurred during clearing persistent storage.
echo.
goto ERROR


:ALT_INST
rem ********************************************************************************
rem If Altiris, need to do some custom work here.
rem ********************************************************************************
echo Loading smartdrv
%TKDRV%\bootwiz\dos\smartdrv C+ 4096 4096 /v > nul



:FORMATS
rem ********************************************************************************
rem * Format the hard drive
rem ********************************************************************************
echo Formatting the NOS partition
format32.com c: /q /autotest > nul

rem ********************************************************************************
rem * Check for errors: FORMAT32.COM
rem ********************************************************************************
if not errorlevel 1 goto COPYSGDD
echo An error occurred during formatting.
echo.
goto ERROR


:COPYSGDD
rem ********************************************************************************
rem * Copies the ServerGuide set of device drivers to the NOS partition
rem ********************************************************************************
echo Copying the set of device drivers to the NOS partition
call copysgdd.bat


rem ********************************************************************************
rem * Check for errors from COPYSGDD
rem ********************************************************************************
rem echo Checking for errors from copysgdd
savestat.exe /get2 > nul

rem ********************************************************************************
rem * Check for errors: SAVESTAT.EXE
rem ********************************************************************************
FOR %%i in (251 255) do if errorlevel %%i goto ERROR


rem ********************************************************************************
rem * If Altiris, provide status
rem ********************************************************************************
if %DPLY_TYPE%==4 goto AM1
goto MPCLI

:AM1
%TKDRV%\logevent.exe -c:0 -l:1 -ss:"INSTOS:  Successfully copied ServerGuide device driver set."


:MPCLI
rem ********************************************************************************
rem * USER:  Add necessary statements here to copy of the MPCLI program files
rem *        to NOS partition.
rem ********************************************************************************



:COPYUNAT
rem ********************************************************************************
rem * Copy unattend.txt to NOS partition
rem ********************************************************************************
echo Copying the unattend.txt file
copy %ANS_PATH%\%ANS_FILE% %NOSDRV%\%WRK_DIR% > nul

rem ********************************************************************************
rem * Check for errors: COPY.EXE
rem ********************************************************************************
if not errorlevel 1 goto HWDETECT
echo An error occurred during copy.
echo.
goto ERROR


:HWDETECT

rem ********************************************************************************
rem * If Altiris, provide status
rem ********************************************************************************
if %DPLY_TYPE%==4 goto AM2
goto HW1

:AM2
%TKDRV%\logevent.exe -c:0 -l:1 -ss:"INSTOS:  Successfully copied unattend.txt file."

:HW1
rem ********************************************************************************
rem * Perform hardware detect, in order to update the unattend.txt with hardware 
rem * specific information.
rem ********************************************************************************
echo Running hardware detection
HWDetect.exe /i > %NOSDRV%\%WRK_DIR%\HWDetect.ini


rem ********************************************************************************
rem * Check for errors: HWDETECT
rem ********************************************************************************
if not errorlevel 1 goto CUSTUNAT
echo An error occurred during hwdetect.
echo.
goto ERROR


:CUSTUNAT
rem ********************************************************************************
rem * USER:  Uncomment this line to activate the calling of the batch file for the
rem * user customization of unattend.txt located on the NOS partition here.  Make
rem * the required changes in the CustUnat.bat file.
rem ********************************************************************************

REM call custunat.bat


:GENTXTMOD
rem ********************************************************************************
rem * Dynamically generate the TEXTMODE directory, based on target system information
rem ********************************************************************************
echo Dynamically generate the TEXTMODE directory, based on target system information
call gentxtmd.bat


rem ********************************************************************************
rem * Check for errors from GENTXTMD
rem ********************************************************************************
rem echo Checking for errors from gentxtmd
savestat.exe /get2 > nul

rem ********************************************************************************
rem * Check for errors: SAVESTAT.EXE
rem *
rem * The errorlevel here controls the installation process.
rem ********************************************************************************
FOR %%i in (251 255) do if errorlevel %%i goto ERROR


rem ********************************************************************************
rem * If Altiris, provide status
rem ********************************************************************************
if %DPLY_TYPE%==4 goto AM3
goto UNATTEND

:AM3
%TKDRV%\logevent.exe -c:0 -l:1 -ss:"INSTOS:  Successfully generated the textmode directory."


:UNATTEND
rem ********************************************************************************
rem * Update unattend.txt with hardware specific information.
rem ********************************************************************************
echo Add hardware specific driver information to the unattend.txt file
call unattend.bat


rem ********************************************************************************
rem * Check for errors:  UNATTEND.BAT
rem ********************************************************************************
savestat.exe /get2 > nul


rem ********************************************************************************
rem * Check for errors: SAVESTAT.EXE
rem *
rem * The errorlevel here controls the installation process.
rem ********************************************************************************
FOR %%i in (251 255) do if errorlevel %%i goto ERROR


rem ********************************************************************************
rem * If Altiris, provide status
rem ********************************************************************************
if %DPLY_TYPE%==4 goto AM4
goto RUNWINNT

:AM4
%TKDRV%\logevent.exe -c:0 -l:1 -ss:"INSTOS:  Successfully added hardware information to unattend.txt file."


:RUNWINNT
rem ********************************************************************************
rem * Launch the Windows OS installation.  The automatic reboot called by winnt.exe 
rem * is suppressed, with the /W, so that this batch file can regain control 
rem * in order to do more work.
rem ********************************************************************************
set RBF=/W

rem * If doing an Altiris installation, let winnt.exe call reboot
if %DPLY_TYPE% == 4  set RBF=

echo Running Windows winnt.exe...
%OS_PATH%\i386\WinNT.exe /S:%OS_PATH%\i386 /U:\%WRK_DIR%\%ANS_FILE% /RX:lang %RBF%

rem ********************************************************************************
rem * Check for errors:  WINNT.EXE
rem ********************************************************************************
if not errorlevel 1 goto RM_MEDIA
echo An error occurred running the winnt.exe program.

rem * Reset the TKDRV to root
%TKDRV%
cd \
%NOSDRV%
goto ERROR


:RM_MEDIA
rem ********************************************************************************
rem * This section controls whether the user is prompted to take out the bootable 
rem * media or not.   If the user indicated that the boot media is write protected,
rem * then we MUST always prompt the user to remove the media.   Otherwise, we
rem * check if the user wants to alter the diskette boot sector by calling altboot.exe.
rem *
rem * NOTE:  If the diskette is changed using altboot, then this diskette will not
rem * be bootable again UNTIL it is restored OUTSIDE the ServerGuide Scripting
rem * Toolkit installation process.
rem ********************************************************************************

rem *********************************************************************
rem * Defines the type of prompting to use during deployment.  
rem * Valid values are: 
rem *   0 - Always prompt the user to remove the boot media. Boot media 
rem *       is unaltered.
rem *   1 - Run altboot.exe to disable a writable boot diskette.  This 
rem *       means the user will not be prompted to remove the boot media, 
rem *       allowing for the complete automation of the installation process.
rem *   2 - Boot media is write protected, user will be prompted to remove 
rem *       the non-writable boot media.  (REQUIRED for bootable CDs)
rem *   3 - Deployment will be via a RSA-II adapter.  Deployment will exit 
rem *       automatically so that the boot media can be unmounted.
rem *   4 - Deployment using Altiris(R).
rem *********************************************************************
if %DPLY_TYPE% == 0 goto ASKUSER
if %DPLY_TYPE% == 1 goto ALTBOOT
if %DPLY_TYPE% == 2 goto ASKUSER
if %DPLY_TYPE% == 3 goto VFLOP
if %DPLY_TYPE% == 4 goto ALTSTAT0


:ALTBOOT
rem ********************************************************************************
rem * Run Altboot utility to disable booting from the floppy and boot directly from
rem * the hard drive.
rem ********************************************************************************
echo Running altboot.exe based on variable set in usrvars.bat
altboot.exe /h  > nul

rem ********************************************************************************
rem * Check for errors:  ALTBOOT.EXE
rem ********************************************************************************
if not errorlevel 1 goto FNREBOOT
echo An error occurred during running altboot.exe
echo.
goto ERROR


:ASKUSER
rem ********************************************************************************
rem * Ask user to remove boot media.   This path is used when the boot media is 
rem * write protected or when the user does NOT want to alter their boot media.
rem ********************************************************************************
if exist A:\_BOOT_HD.NOZ goto FNREBOOT

echo Please remove bootable media at this time.  
pause

goto FNREBOOT

:FNREBOOT
rem ********************************************************************************
rem * This is the suppressed reboot from winnt.exe.   Once this reboot is called, 
rem * the ServerGuide Scripting Toolkit installation process is over and then
rem * Microsoft's installation will be in control until the installation is complete.
rem ********************************************************************************
echo This is the final reboot from ServerGuide Scripting Toolkit.

sleep 15
%RAMDSK%\reboot.com

goto END

:VFLOP
rem ********************************************************************************
rem * Tell the user to umount the boot media.   This path is used when installing
rem * using a RSA-II adapter.  
rem ********************************************************************************
cls
echo The ServerGuide Scripting Toolkit processing is complete.  
echo.
echo In order to complete the operating system installation on the target
echo system, please perform the following tasks:
echo    1.  Unmount the Toolkit remote disk.
echo    2.  Restart of the target system.
echo.
echo.
goto END


:ERROR
rem ********************************************************************************
rem * Hit an error in this batch file.
rem ********************************************************************************
echo Encountered an error and stopped processing in "instos.bat".

rem * If doing an Altiris installation, jump to status
if %DPLY_TYPE%==4 goto ALTSTAT1

savestat.exe /set2=251 > nul
goto END


:ALTSTAT0
rem ********************************************************************************
rem Update Altiris with necessary status
rem ********************************************************************************
echo Updating Altiris status: Good
%TKDRV%\logevent.exe -c:0 -l:1 -ss:"INSTOS:  Completed successfully."

rem Reset to root of Toolkit drive
%TKDRV%
cd \

goto END


:ALTSTAT1
rem ********************************************************************************
rem Update Altiris with necessary status
rem ********************************************************************************
echo Updating Altiris status: Error
%TKDRV%\logevent.exe -c:251 -l:3 -ss:"INSTOS:  Encountered an error."

rem Reset to root of Toolkit drive
%TKDRV%
cd \

rem Reset persistent storage
savestat.exe /reset > nul
goto END

:END
set RBF=
