@echo off

rem ********************************************************************************
rem *
rem * PREPPART.BAT
rem *
rem * This file creates a NOS partition for the Microsoft(R) Windows installation
rem * scenarios for the ServerGuide Scripting Toolkit.  
rem * 
rem * This batch file clears the first hard drive of any existing partitions, then 
rem * it creats a new, single partition, whose size is determined by the 
rem * PARTITION_SIZE environment variable, set in usrvars.bat.
rem *
rem * This batch file is called by the runinst.bat.
rem *
rem ********************************************************************************


:FDDELETE
rem ********************************************************************************
rem * Delete any existing partitions on the first hard drive found in the system.
rem ********************************************************************************
echo Remove any existing partitions
fdisk32.com 1 /delete:all

rem ********************************************************************************
rem * Check for errors: FDISK32.COM
rem ********************************************************************************
if not errorlevel 1 goto FDCREATE
echo An error occurred during deleting partitions.
echo.
goto ERROR


:FDCREATE
rem ********************************************************************************
rem * Create new NOS partition.  The partition size is set in usrvars.bat.
rem ********************************************************************************
echo Create new partition
fdisk32.com 1 /pri:%PART_SZ%

rem ********************************************************************************
rem * Check for errors: FDISK32.COM
rem ********************************************************************************
if not errorlevel 1 goto FDSAVEST
echo An error occurred during creating partitions.
echo.
goto ERROR


:FDSAVEST
rem ********************************************************************************
rem * Write information to persistent storage that will identify what installation
rem * steps have been completed so far, and control where processing resumes after 
rem * the reboot.
rem ********************************************************************************

rem ********************************************************************************
rem * If doing an Altiris installation, jump to status
rem ********************************************************************************
if %DPLY_TYPE%==4 goto ALTSTAT0

echo Save step location to return after reboot
savestat.exe /set2=100 > nul

rem ********************************************************************************
rem * Check for errors: SAVESTAT.EXE
rem ********************************************************************************
if not errorlevel 255 goto FDREBOOT
echo An error occurred during writing to persistent storage.
echo.
goto ERROR


:FDREBOOT
rem ********************************************************************************
rem * Reboot the system.  Control will return to runinst.bat and processing will
rem * continue.
rem ********************************************************************************
echo Now, reboot the machine

sleep 15
reboot.com
goto END


:ERROR
rem ********************************************************************************
rem * Hit an error in this batch file.
rem ********************************************************************************
echo Encountered an error and stopped processing in "preppart.bat".

rem ********************************************************************************
rem * If doing an Altiris installation, jump to status
rem ********************************************************************************
if %DPLY_TYPE%==4 goto ALTSTAT1

savestat.exe /set2=251 > nul

goto END

:ALTSTAT0
rem ********************************************************************************
rem * Update Altiris with necessary status
rem ********************************************************************************
echo Updating Altiris status: Good
%TKDRV%\logevent.exe -c:0 -l:1 -ss:"PREPPART: Completed successfully."

rem Reset to root of Toolkit drive
%TKDRV%
cd \

goto END


:ALTSTAT1
rem ********************************************************************************
rem * Update Altiris with necessary status
rem ********************************************************************************
echo Updating Altiris status: Error
%TKDRV%\logevent.exe -c:251 -l:3 -ss:"PREPPART:  Encountered an error."

rem Reset to root of Toolkit drive
%TKDRV%
cd \

goto END


:END
